/******************************************************************************
  This source file is part of the Avogadro project.
  This source code is released under the 3-Clause BSD License, (see "LICENSE").
******************************************************************************/

#include "visitor.h"

namespace Avogadro::Rendering {

Visitor::Visitor() {}

Visitor::~Visitor() {}

} // namespace Avogadro::Rendering
